@@ -4,12 +4,10 @@
 
 import logging
 
-from django.utils import timezone
-
 from psycopg2.extensions import ISQLQuote
 
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 __author__ = 'Jay Taylor [@jtaylor]'
 
 
@@ -42,15 +40,16 @@ class CurrentTimestamp(object):
     @classmethod
     def patch(cls, field):
         orig_pre_save = field.pre_save
-        orig_get_db_prep_value = field.get_db_prep_value
-        orig_get_prep_lookup = field.get_prep_lookup
-        orig_get_db_prep_lookup = field.get_db_prep_lookup
+        orig_prep_db = field.get_db_prep_value
+        orig_prep_lookup = field.get_prep_lookup
+        orig_db_prep_lookup = field.get_db_prep_lookup
 
         def pre_save(self, model_instance, add):
             """
             Pre-save `CURRENT_TIMESTAMP` injector.
             NB: The returned value is what will go into the database, and the `timezone.now()` value will be set on the model instance.
             """
+            from django.utils import timezone # Import here to avoid `pip install ..` issues.
             if self.auto_now or (self.auto_now_add and add):
                 value = CurrentTimestamp()
                 setattr(model_instance, self.attname, timezone.now()) # Attach an approximate TS to the object.
@@ -58,25 +57,25 @@ class CurrentTimestamp(object):
             else:
                 return orig_pre_save(self, model_instance, add)
 
-        def get_db_prep_value(self, value, connection, prepared=False):
-            result = value if isinstance(value, cls) else orig_get_db_prep_value(self, value, connection, prepared)
+        def prep_db_value(self, value, connection, prepared=False):
+            result = value if isinstance(value, cls) else orig_prep_db(self, value, connection, prepared)
             #logger.debug('prep_db_value :: name={} type(result)={} result={}'.format(self.name, type(result), result))
             return result
 
-        def get_prep_lookup(self, lookup_type, value):
-            result = value if isinstance(value, cls) else orig_get_prep_lookup(self, lookup_type, value)
+        def prep_lookup(self, lookup_type, value):
+            result = value if isinstance(value, cls) else orig_prep_lookup(self, lookup_type, value)
             #logger.debug('prep_lookup :: name={} type(result)={} result={}'.format(self.name, type(result), result))
             return result
 
-        def get_prep_db_lookup(self, lookup_type, value, connection, prepared=True):
-            result = value if isinstance(value, cls) else orig_get_db_prep_lookup(self, lookup_type, value, connection=connection, prepared=True)
+        def prep_db_lookup(self, lookup_type, value, connection, prepared=True):
+            result = value if isinstance(value, cls) else orig_db_prep_lookup(self, lookup_type, value, connection=connection, prepared=True)
             #logger.debug('prep_db_lookup :: name={} type(result)={} result={}'.format(self.name, type(result), result))
             return result
 
         field.pre_save = pre_save
-        field.get_db_prep_value = get_db_prep_value
-        field.get_prep_lookup = get_prep_lookup
-        field.get_db_prep_lookup = get_prep_db_lookup
+        field.get_db_prep_value = prep_db_value
+        field.get_prep_lookup = prep_lookup
+        field.get_db_prep_lookup = prep_db_lookup
 
 
 def init():
